@@ -18,11 +18,11 @@ URI::NamespaceMap - Class holding a collection of namespaces
 
 =head1 VERSION
 
-Version 0.28
+Version 0.32
 
 =cut
 
-our $VERSION = '0.28';
+our $VERSION = '0.32';
 
 
 =head1 SYNOPSIS
@@ -115,6 +115,25 @@ sub namespace_uri   { $_[0]->namespace_map->{$_[1]} }
 sub list_namespaces { values %{ $_[0]->namespace_map } }
 sub list_prefixes   { keys   %{ $_[0]->namespace_map } }
 
+
+=item C<< guess_and_add ( @string_or_uri ) >>
+
+Like in the constructor, an array of strings can be given, and the
+module will attempt to guess appropriate mappings, and add them to the
+map.
+
+=cut
+
+sub guess_and_add {
+	my ($self, @data) = @_;
+	my $guessed = $self->_guess(@data);
+	while (my ($name, $uri) = each %{$guessed}) {
+		$self->add_mapping($name => $uri);
+	}
+}
+
+
+
 =item C<< uri ( $prefixed_name ) >>
 
 Returns a URI for an abbreviated string such as 'foaf:Person'.
@@ -261,7 +280,7 @@ sub _guess {
 		
 		if ($entry =~ m/^[a-z]\w+$/i) {
 			# This is a prefix
-			warn "Cannot resolve '$entry' without RDF::NS::Curated, XML::CommonNS, RDF::NS" unless ($rnscu || $xmlns || $rdfns);
+			carp "Cannot resolve '$entry' without RDF::NS::Curated, XML::CommonNS, RDF::NS" unless ($rnscu || $xmlns || $rdfns);
 			if ($rnscu) {
 				my $ns = RDF::NS::Curated->new;
 				$namespaces{$entry} = $ns->uri($entry);
@@ -277,10 +296,10 @@ sub _guess {
 				my $ns = RDF::NS->new;
 				$namespaces{$entry} = $ns->SELECT($entry);
 			}
-			warn "Cannot resolve '$entry'" unless $namespaces{$entry};
+			carp "Cannot resolve '$entry'" unless $namespaces{$entry};
 		} else {
 			# Lets assume a URI string
-			warn "Cannot resolve '$entry' without RDF::NS::Curated, RDF::NS or RDF::Prefixes" unless ($rnscu || $rdfns || $rdfpr);
+			carp "Cannot resolve '$entry' without RDF::NS::Curated, RDF::NS or RDF::Prefixes" unless ($rnscu || $rdfns || $rdfpr);
 			my $prefix;
 			if ($rnscu) {
 				my $ns = RDF::NS::Curated->new;
@@ -295,7 +314,7 @@ sub _guess {
 				$prefix = $context->get_prefix($entry);
 			}
 			unless ($prefix) {
-				warn "Cannot resolve '$entry'";
+				carp "Cannot resolve '$entry'";
 			} else {
 				$namespaces{$prefix} = $entry;
 			}
@@ -338,7 +357,7 @@ You can find documentation for this module with the perldoc command.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2012-2014 Gregory Todd Williams, Chris Prather and Kjetil Kjernsmo
+Copyright 2012,2013,2014,2015,2016 Gregory Todd Williams, Chris Prather and Kjetil Kjernsmo
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
